Python: module TileStache.Goodies.Providers.GDAL

TileStache.Goodies.Providers.GDAL | index

`Minimally-tested GDAL image provider.
Based on existing work in OAM (https://github.com/oam/oam), this GDAL provider
is the bare minimum necessary to do simple output of GDAL data sources.
Sample configuration:
"provider":
{
"class": "TileStache.Goodies.Providers.GDAL:Provider",
"kwargs": { "filename": "landcover-1km.tif", "resample": "linear", "maskband": 2 }
}
Valid values for resample are "cubic", "cubicspline", "linear", and "nearest".
The maskband argument is optional. If present and greater than 0, it specifies
the GDAL dataset band whose mask should be used as an alpha channel. If maskband
is 0 (the default), do not create an alpha channel.
With a bit more work, this provider will be ready for fully-supported inclusion
in TileStache proper. Until then, it will remain here in the Goodies package.`

Modules
`` |  |
PIL.Image | osgeo.gdal | osgeo.osr |

Classes
`` |  | Provider
class Provider
`` |  | Methods defined here: __init__(self, layer, filename, resample='cubic', maskband=0) renderArea(self, width, height, srs, xmin, ymin, xmax, ymax, zoom)

Data
`` |  | resamplings = {'cubic': 2, 'cubicspline': 3, 'linear': 1, 'nearest': 0}